| .validate_pedigree | R Documentation |
This internal function checks if the input object is of class ped. If not, it stops execution with an error message. Additionally, it can check for forbidden names in the pedigree IDs if specified.
.validate_pedigree(pedigree, disallow_U_names = FALSE)
pedigree |
An object that is expected to be of class |
disallow_U_names |
A logical flag indicating whether to disallow IDs starting with "U" followed by a digit (e.g., "U1", "U2", ..., "U10") in the pedigree. Default is |
This function does not return a value. It stops execution if the input is not of class ped or if forbidden names are found when disallow_U_names is TRUE.
## Not run:
pedigree <- create_ped() # Assuming create_ped() returns an object of class 'ped'
.validate_pedigree(pedigree)
.validate_pedigree(pedigree, disallow_U_names = TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.